%% Sinusoidal Response
% This file plots the sinusodial response for a stable first-order system.


%% System (Transfer Function and State-Space Form)
b0 = 2;
a0 = 4;
Gtf = tf(b0,[1 a0]);

Gss = ss(-a0,b0,1,0);

%% Sinusoidal Response
w = [2 4];         % Frequencies to simulate, rad/sec
Nw = numel(w);

for i=1:Nw
    % Simulate system
    y0 = 1.5;
    Tf = 3*pi;
    t = linspace(0,Tf,50*Tf);
    u = sin(w(i)*t);
    [y,t] = lsim(Gss,u,t,y0);
    
    % Plot results
    figure(i);clf
    plot(t,u,'b-.',t,y,'r')
    xlim([0 Tf]);
    xlabel('Time, t (sec)');
    ylabel('Output, y');
    grid on;
    legend('u','y','Location','Best');

    % Evaluate TF at specified frequency
    Gw = evalfr(Gtf,j*w(i));
    Gmag = abs(Gw);
    Gph = angle(Gw);
    
    % Plot zero-crossing for output
    hold on;
    tcross = 2*pi - Gph/w(i)
    ph(1,i) = plot(tcross*[1 1],[0 1.2],'k');
    th(i) = text(tcross,1.3,['t = ' num2str(tcross,'%1.3f')]);
    hold off;
    
    % Set tick labels and axis properties
    set(gca,'Xtick',0:pi/2:Tf,'XtickLabel',...
        {'0', '\pi/2', '\pi', '3\pi/2','2\pi', '5\pi/2', '3\pi'});
    if i==1
        set(gca,'Ytick',[-1 -0.447 0 0.447 1 1.5]);
    else
        set(gca,'Ytick',[-1 -0.354 0 0.354 1 1.5]);
    end
    set(gca,'LineWidth',1)
    set(gca, 'LooseInset', get(gca, 'TightInset'));
end

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(1)
    garyfyFigure
    
    figure(2)
    garyfyFigure
    
    set(ph(:),'LineWidth',1.5);
    set(th,'FontSize',16,'HorizontalAlignment','Center');
    
    myprint(1,'SineResp1')
    myprint(2,'SineResp2')
end
