%% Integrator and Gain
% This file generates the Bode plot of G(s)=Kp/s. For illustration
% this transfer function is expressed as G(s)= Kp*(1/s).  The Bode
% plot of G(s) is then obtained from the Bode plots of Kp and 1/s.

%% Example 1:  Positive Gain

% Form integrator, gain, and their product.
G1 = tf(1,[1 0]);
G2 = tf(10);
G = G1*G2;

% Create Bode Plot
figure(1);
clf
for i=1:3
    w = logspace(-1,1,200);
    if i==1
        [Gmag,Gph_deg,w] = bode(G,w);
        str = 'b';
    elseif i==2
        [Gmag,Gph_deg,w] = bode(G1,w);
        str = 'g-.';
    else
        [Gmag,Gph_deg,w] = bode(G2,w);
        str = 'r:';
    end    
    Gmag = Gmag(:);
    Gph_deg = Gph_deg(:);
    Gmag_dB = 20*log10(Gmag);
    
    % Magnitude Plot
    subplot(2,1,1);
    semilogx(w,Gmag_dB,str);
    hold on;
    ylabel('Magnitude (dB)');
    title('Bode Diagram');
    axis([w(1) w(end) -40 +40])
    grid on;
    set(gca,'LineWidth',2);
    
    % Phase Plot
    subplot(2,1,2);
    semilogx(w,Gph_deg,str);
    hold on;
    ylabel('Phase (deg)');
    xlabel('Frequency (rad/sec)');
    axis([w(1) w(end) -135 +225])
    set(gca,'YTick',[-90 0 90 180]);
    grid on;
    set(gca,'LineWidth',2);
    if i==3
        legend('G','G1','G2','Location','NorthEast');
    end
end

% Save Plots
if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(1)
    garyfyFigure
    myprint(1,'BodeIntAndGain1')
end


%% Example 2:  Negative Gain

% Form integrator, gain, and their product.
G1 = tf(1,[1 0]);
G2 = tf(-0.1);
G = G1*G2;

% Create Bode Plot
figure(2);
clf
for i=1:3
    w = logspace(-1,1,200);
    if i==1
        [Gmag,Gph_deg,w] = bode(G,w);
        str = 'b';
    elseif i==2
        [Gmag,Gph_deg,w] = bode(G1,w);
        str = 'g-.';
    else
        [Gmag,Gph_deg,w] = bode(G2,w);
        str = 'r:';
    end    
    Gmag = Gmag(:);
    Gph_deg = Gph_deg(:);
    Gmag_dB = 20*log10(Gmag);
    
    % Magnitude Plot
    subplot(2,1,1);
    semilogx(w,Gmag_dB,str);
    hold on;
    ylabel('Magnitude (dB)');
    title('Bode Diagram');
    axis([w(1) w(end) -40 +40])
    grid on;
    set(gca,'LineWidth',2);
    
    % Phase Plot
    subplot(2,1,2);
    semilogx(w,Gph_deg,str);
    hold on;
    ylabel('Phase (deg)');
    xlabel('Frequency (rad/sec)');
    axis([w(1) w(end) -135 +225])
    set(gca,'YTick',[-90 0 90 180]);
    grid on;
    set(gca,'LineWidth',2);
    if i==3
        legend('G','G1','G2','Location','NorthEast');
    end
end

% Save Plots
if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(2)
    garyfyFigure
    myprint(2,'BodeIntAndGain2')
end

